@@ -13,6 +13,8 @@
 #include <QQuickItem>
 #include <QVariant>
 
+#include <QQmlEngine>
+
 class QNetworkReply;
 class QQuickWindow;
 class QPropertyAnimation;
@@ -32,6 +34,7 @@ class Units;
 class Icon : public QQuickItem
 {
     Q_OBJECT
+    QML_ELEMENT
 
     /**
      * The source of this icon. An `Icon` can pull from:
@@ -279,7 +282,7 @@ private:
     // animation on image change
     QPropertyAnimation *m_animation = nullptr;
     qreal m_animValue = 1.0;
-    bool m_animated = true;
+    bool m_animated = false;
     bool m_roundToIconSize = true;
     bool m_allowNextAnimation = false;
     bool m_blockNextAnimation = false;
